import { IntlService } from './Intl/IntlService';
import { LocalizationService } from './Localization/LocalizationService';
/**
 * Provides an internationalization service.
 * When the passed component is a direct or indirect child of
 * `IntlProvider`, the returned service uses the locale of the provider.
 * Otherwise, uses `en` as a default locale.
 * To handle locale changes, call the method on each `render`.
 *
 * @param componentClass - The Vue component class that will use the internationalization service.
 */
export declare function provideIntlService(component: any): IntlService;
/**
 * Provides a localization service.
 * When the passed component is a direct or indirect child of
 * `LocalizationProvider`, the returned service uses the language of the provider.
 * To handle locale changes, call the method on each `render`.
 *
 * @param componentClass - The Vue component class that will use the internationalization service.
 */
export declare function provideLocalizationService(component: any): LocalizationService;
